This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] s/Linux/.../


(Canada win 4 - 2.  In late breaking news, the I.O.C. is down playing 
rumours that the Ice Hockey Net is involved in a drug taking scandal ...)
2002-02-24  Andrew Cagney  <ac131313@redhat.com>

 	* lin-lwp.c, thread-db.c, defs.h, cris-tdep.c: Replace ``Linux''
-	with either ``GNU/Linux'' or ``Linux kernel''.
+	with either ``GNU/Linux'' or ``Linux kernel''.  Update copyright.
+	* m68klinux-nat.c, sparc-linux-nat.c, x86-64-linux-nat.c: Ditto.
+	* x86-64-linux-tdep.c, gregset.h, gdb_wait.h: Ditto.
 	Fix PR gdb/378.
 	
Index: gregset.h
===================================================================
RCS file: /cvs/src/src/gdb/gregset.h,v
retrieving revision 1.4
diff -u -r1.4 gregset.h
--- gregset.h	2002/01/14 20:00:47	1.4
+++ gregset.h	2002/02/24 22:04:13
@@ -37,7 +37,7 @@
    includes integer registers and control registers.  An fpregset is a
    data structure containing the floating point registers.  These data
    structures were originally a part of the /proc interface, but have
-   been borrowed or copied by other GDB targets, eg. Linux.  */
+   been borrowed or copied by other GDB targets, eg. GNU/Linux.  */
 
 /* Copy register values from the native target gregset/fpregset
    into GDB's internal register cache.  */
Index: sparc-linux-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/sparc-linux-nat.c,v
retrieving revision 1.2
diff -u -r1.2 sparc-linux-nat.c
--- sparc-linux-nat.c	2001/11/17 20:21:09	1.2
+++ sparc-linux-nat.c	2002/02/24 22:04:18
@@ -1,5 +1,6 @@
-/* Native-dependent code for Linux/SPARC.
-   Copyright 2001 Free Software Foundation, Inc.
+/* Native-dependent code for GNU/Linux SPARC.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: x86-64-linux-tdep.c
===================================================================
RCS file: /cvs/src/src/gdb/x86-64-linux-tdep.c,v
retrieving revision 1.3
diff -u -r1.3 x86-64-linux-tdep.c
--- x86-64-linux-tdep.c	2001/09/25 10:37:17	1.3
+++ x86-64-linux-tdep.c	2002/02/24 22:04:18
@@ -1,6 +1,7 @@
-/* Target-dependent code for Linux running on x86-64, for GDB.
-   Copyright 2001
-   Free Software Foundation, Inc.
+/* Target-dependent code for GNU/Linux running on x86-64, for GDB.
+
+   Copyright 2001 Free Software Foundation, Inc.
+
    Contributed by Jiri Smid, SuSE Labs.
 
    This file is part of GDB.
@@ -71,8 +72,8 @@
 /* Offset to struct sigcontext in ucontext, from <asm/ucontext.h>.  */
 #define LINUX_UCONTEXT_SIGCONTEXT_OFFSET (36)
 
-/* Assuming FRAME is for a Linux sigtramp routine, return the address
-   of the associated sigcontext structure.  */
+/* Assuming FRAME is for a GNU/Linux sigtramp routine, return the
+   address of the associated sigcontext structure.  */
 CORE_ADDR
 x86_64_linux_sigcontext_addr (struct frame_info *frame)
 {
@@ -102,8 +103,8 @@
 /* Offset to saved PC in sigcontext, from <asm/sigcontext.h>.  */
 #define LINUX_SIGCONTEXT_PC_OFFSET (136)
 
-/* Assuming FRAME is for a Linux sigtramp routine, return the saved
-   program counter.  */
+/* Assuming FRAME is for a GNU/Linux sigtramp routine, return the
+   saved program counter.  */
 
 CORE_ADDR
 x86_64_linux_sigtramp_saved_pc (struct frame_info *frame)

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: gdb_wait.h
===================================================================
RCS file: /cvs/src/src/gdb/gdb_wait.h,v
retrieving revision 1.3
diff -u -r1.3 gdb_wait.h
--- gdb_wait.h	2000/03/18 01:57:00	1.3
+++ gdb_wait.h	2002/02/24 22:04:13
@@ -39,8 +39,8 @@
 /* The following macros are defined equivalently to their definitions
    in POSIX.1.  We fail to define WNOHANG and WUNTRACED, which POSIX.1
    <sys/wait.h> defines, since our code does not use waitpid() (but
-   NOTE exception for Linux below).
-   We also fail to declare wait() and waitpid().  */   
+   NOTE exception for GNU/Linux below).  We also fail to declare
+   wait() and waitpid().  */
 
 #ifndef	WIFEXITED
 #define WIFEXITED(w)	(((w)&0377) == 0)
@@ -101,11 +101,9 @@
 # endif
 #endif
 
-/*
- * For native Linux we may use waitpid and the __WCLONE option.
- *  <GRIPE> It is of course dangerous not to use the REAL header file...
- * </GRIPE>
- */
+/* For native GNU/Linux we may use waitpid and the __WCLONE option.
+  <GRIPE> It is of course dangerous not to use the REAL header file...
+  </GRIPE>.  */
 
 /* Bits in the third argument to `waitpid'.  */
 #ifndef WNOHANG
Index: i386-linux-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/i386-linux-nat.c,v
retrieving revision 1.34
diff -u -r1.34 i386-linux-nat.c
--- i386-linux-nat.c	2002/01/09 22:32:16	1.34
+++ i386-linux-nat.c	2002/02/24 22:04:17
@@ -1,4 +1,5 @@
-/* Native-dependent code for Linux/x86.
+/* Native-dependent code for GNU/Linux x86.
+
    Copyright 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
@@ -66,10 +67,10 @@
 
 
 
-/* The register sets used in Linux ELF core-dumps are identical to the
-   register sets in `struct user' that is used for a.out core-dumps,
-   and is also used by `ptrace'.  The corresponding types are
-   `elf_gregset_t' for the general-purpose registers (with
+/* The register sets used in GNU/Linux ELF core-dumps are identical to
+   the register sets in `struct user' that is used for a.out
+   core-dumps, and is also used by `ptrace'.  The corresponding types
+   are `elf_gregset_t' for the general-purpose registers (with
    `elf_greg_t' the type of a single GP register) and `elf_fpregset_t'
    for the floating-point registers.
 
@@ -593,7 +594,7 @@
       return;
     }
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);		/* Not a threaded program.  */
 
@@ -659,7 +660,7 @@
       return;
     }
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
 
@@ -778,7 +779,7 @@
 /* Provide registers to GDB from a core file.
 
    (We can't use the generic version of this function in
-   core-regset.c, because Linux has *three* different kinds of
+   core-regset.c, because GNU/Linux has *three* different kinds of
    register set notes.  core-regset.c would have to call
    supply_fpxregset, which most platforms don't have.)
 
@@ -791,7 +792,7 @@
      2 --- the floating-point register set, in elf_fpregset_t format
      3 --- the extended floating-point register set, in elf_fpxregset_t format
 
-   REG_ADDR isn't used on Linux.  */
+   REG_ADDR isn't used on GNU/Linux.  */
 
 static void
 fetch_core_registers (char *core_reg_sect, unsigned core_reg_size,
@@ -847,7 +848,7 @@
 }
 
 
 /* The instruction for a Linux system call is:
        int $0x80
    or 0xcd 0x80.  */
 
@@ -935,7 +936,8 @@
 }
 
 
-/* Register that we are able to handle Linux ELF core file formats.  */
+/* Register that we are able to handle GNU/Linux ELF core file
+   formats.  */
 
 static struct core_fns linux_elf_core_fns =
 {
@@ -593,7 +594,7 @@
     }
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);		/* Not a threaded program.  */
@@ -659,7 +660,7 @@
     }
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
@@ -847,7 +848,7 @@
 
 
-/* The instruction for a Linux system call is:
+/* The instruction for a GNU/Linux system call is:
        int $0x80
    or 0xcd 0x80.  */
Index: m68klinux-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/m68klinux-nat.c,v
retrieving revision 1.8
diff -u -r1.8 m68klinux-nat.c
--- m68klinux-nat.c	2002/01/30 13:57:33	1.8
+++ m68klinux-nat.c	2002/02/24 22:04:18
@@ -1,6 +1,8 @@
-/* Motorola m68k native support for Linux
-   Copyright 1996, 1998, 2000, 2001 Free Software Foundation, Inc.
+/* Motorola m68k native support for GNU/Linux.
 
+   Copyright 1996, 1998, 2000, 2001, 2002 Free Software Foundation,
+   Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -445,7 +447,7 @@
       return;
     }
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);		/* Not a threaded program.  */
 
@@ -500,7 +502,7 @@
       return;
     }
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
 
@@ -546,7 +548,7 @@
      0 --- the general-purpose register set, in elf_gregset_t format
      2 --- the floating-point register set, in elf_fpregset_t format
 
-   REG_ADDR isn't used on Linux.  */
+   REG_ADDR isn't used on GNU/Linux.  */
 
 static void
 fetch_core_registers (char *core_reg_sect, unsigned core_reg_size,
@@ -627,7 +629,8 @@
 }
 
 
-/* Register that we are able to handle Linux ELF core file formats.  */
+/* Register that we are able to handle GNU/Linux ELF core file
+   formats.  */
 
 static struct core_fns linux_elf_core_fns =
 {
@@ -445,7 +447,7 @@
     }
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);		/* Not a threaded program.  */
@@ -500,7 +502,7 @@
     }
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
Index: x86-64-linux-nat.c
===================================================================
RCS file: /cvs/src/src/gdb/x86-64-linux-nat.c,v
retrieving revision 1.4
diff -u -r1.4 x86-64-linux-nat.c
--- x86-64-linux-nat.c	2002/01/20 09:29:41	1.4
+++ x86-64-linux-nat.c	2002/02/24 22:04:18
@@ -1,4 +1,4 @@
-/* Native-dependent code for Linux/x86-64.
+/* Native-dependent code for GNU/Linux x86-64.
 
    Copyright 2001, 2002 Free Software Foundation, Inc.
 
@@ -109,8 +109,8 @@
 }
 
 
-/* The register sets used in Linux ELF core-dumps are identical to the
-   register sets used by `ptrace'.  */
+/* The register sets used in GNU/Linux ELF core-dumps are identical to
+   the register sets used by `ptrace'.  */
 
 #define GETREGS_SUPPLIES(regno) \
   (0 <= (regno) && (regno) <= 17)
@@ -247,7 +247,7 @@
 {
   int tid;
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
 
@@ -282,7 +282,7 @@
 {
   int tid;
 
   /* Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
 
@@ -499,7 +499,7 @@
      0 --- the general-purpose register set, in elf_gregset_t format
      2 --- the floating-point register set, in elf_fpregset_t format
 
-   REG_ADDR isn't used on Linux.  */
+   REG_ADDR isn't used on GNU/Linux.  */
 
 static void
 fetch_core_registers (char *core_reg_sect, unsigned core_reg_size,
@@ -537,7 +537,7 @@
     }
 }
 
 /* Register that we are able to handle Linux ELF core file formats.  */
 
 static struct core_fns linux_elf_core_fns = {
   bfd_target_elf_flavour,	/* core_flavour */
@@ -247,7 +247,7 @@
   int tid;
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
@@ -282,7 +282,7 @@
   int tid;
 
-  /* Linux LWP ID's are process ID's.  */
+  /* GNU/Linux LWP ID's are process ID's.  */
   if ((tid = TIDGET (inferior_ptid)) == 0)
     tid = PIDGET (inferior_ptid);	/* Not a threaded program.  */
@@ -537,7 +537,7 @@
 }
 
-/* Register that we are able to handle Linux ELF core file formats.  */
+/* Register that we are able to handle GNU/Linux ELF core file formats.  */
 
 static struct core_fns linux_elf_core_fns = {